<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL: https://svn.osuosl.org/public/maintain-project/tags/release-3.0.0-RC1/class/dao/extended/pointer.php $
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |       
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Author(s): Daniel Robert <robert@osuosl.org>                           |
// +------------------------------------------------------------------------+
// $Id: pointer.php 4644 2006-07-24 17:58:44Z schonstal $

/**
  * pointer.php - contains the {@link Pointer} class
  *
  * @author $Author: schonstal $
  * @filesource
  * @package    classes
  * @subpackage dao
  */

include_once DAODIR.'/Pointer.php';

/**
  * A forward or reverse Pointer
  *
  * @package    classes
  * @subpackage dao
  */
class Pointer extends DAO_Pointer {

    // {{{ constructor()

    /**
      * Constructor
      *
      * @param  int Pointer ID (primary key)
      */
	function Pointer ( $pointer_id = 0 ) 
    {
        if ($pointer_id) {
            $this->id = $pointer_id;
            $this->get($pointer_id);
        }
    }
    // }}}

/* Overloaded Maintain Internals */
    // {{{ setAll()

    /**
      * Call all set*() methods to 
      * ensure internal objects/variables
      * are up-to-date
      */
    function setAll() {
        
        $this->setIp($this->ip);
        $this->setEnabled($this->enabled);
        $this->setType($this->type);
        $this->setTtl($this->ttl);
    }

    // }}}

/* Setters */
    // {{{ setIp()
    function setIp($new_ip) 
    {
        $this->ipobj = new IP($new_ip);
        $this->ip = $this->ipobj->ip_int;

        return true;
    }
    // }}}
    // {{{ setEnabled()
    function setEnabled($enable) 
    {
        if ($enable === 'false' || $enable === false || $enable === 0) {
            $this->enabled = 0;
        } else {
            $this->enabled = 1;
        }
      
        return true;
    }
    // }}}
    // {{{ setType()
    function setType($type) {
        if (isset($type))
            $this->type = strtolower($type);

        return true;
    }
    // }}}
    // {{{ setTtl()
    function setTtl($ttl)
    {
        global $conf;

        if (!isset($ttl)) {
            $this->ttl = $conf['soa']['default_pointer_ttl'];
        } else {
            $this->ttl = $ttl;
        }

        return true;
    }
    // }}}

/* Getters */
    // {{{ getIp()
    function getIp()
    {
        return $this->ipobj->ip_addr;
    }
    // }}}
    // {{{ getHostname()
    function getHostname()
    {
        if (!$this->hostname) {
            $this->setName($this->name);
        }

        return $this->hostname;
    }

    // }}}

/* Validators */
    // {{{ validateHostname()
    function validateHostname() 
    {
        global $conf;

        // validate hostname syntax first
        if (!Domain::is_valid_name($this->hostname))
            return _("Invalid hostname");

        /* is there a cname? */

		$sql = "SELECT cname.id FROM cname,domain WHERE cname.domain = domain.id AND domain.name LIKE '$this->domain' AND cname.name LIKE '$this->name'";
		$db_results = mysql_query($sql, dbh());

		if ($r = mysql_fetch_row($db_results)) {

			$link = "<a href=\"" . web_root() . 
                "cname.php?action=show&amp;id={$r[0]}\">[ "._("Show Cname")." ]</a>";

            return _("There is already a CNAME with the name").
                " $this->hostname ($link)";

        } // if cname

        /* If we are updating we don't need to check this */
        if (isset($this->id))
            return true;
        /* is there a forward pointer? */

         // "SELECT id FROM pointer WHERE hostname LIKE '".$name.$domain."' AND ip='$ip_int' AND type='forward'"
        $dbdo = DB_DataObject::Factory('pointer');
        $dbdo->selectAdd();
        $dbdo->selectAdd('id');
        $dbdo->ip = $this->ip;
        $dbdo->type = 'forward';
        $dbdo->whereAdd("hostname LIKE '$this->hostname'");
        $dbdo->whereAdd("id != '$this->id'");
			
		if ($dbdo->find(true)) {
           
            $link = html_a(web_root()."pointer.php?action=show&amp;id=".$dbdo->id, _("Show Pointer"));
    /*
			$link   = "<a href=\"" . web_root() .
                "pointer.php?action=show&amp;id=$dbdo->id\">[ "._("Show Pointer")." ]</a>";
*/
            $msg    = _("There is already a forward pointer with (hostname -> IP) of");
            $msg    .= " ($this->hostname -> " . IP::int2ip($this->ip) . ") ";

            return $msg . "[ ". $link->render() ." ]";

		} // if a PTR

        return true;
    }
    // }}}
    // {{{ validateIp()
    function validateIp() {
        global $conf, $user;

        //The user must enter a dotted quad; however, with this check, it will still fail with a string because it parses as a non-quad.
        if ($this->ipobj->origin == "other")
            return _("Invalid IP address entered; IP addresses must be entered in valid dotted quad format (x.x.x.x)");

        // "SELECT id FROM pointer WHERE ip='$ip_int' AND id!='$ignore_id' AND type='reverse'"
        $dbdo = DB_DataObject::Factory('pointer');
        $dbdo->selectAdd();
        $dbdo->selectAdd('id');
        $dbdo->ip = $this->ip;
        $dbdo->type = 'reverse';
        $dbdo->whereAdd("id!='{$this->id}'");

        // See if the IP is already in use, isset doesn't need to be checked because of whereAdd
        if ($dbdo->find(true) /*&& !isset($this->id)*/) {
			$link = "<a href=\"" . web_root() .
                "pointer.php?action=show&amp;id=$dbdo->id\">[ Show Pointer ]</a>";

            return _("IP address already in use by a reverse pointer")." $link";
		}

        /* If this is a reverse pointer, the user needs to 
           own the IP address (hostname doesn't matter)
           Also need to make sure that this isn't in a dynamic range
           for obvious reasons...
           */

        if ($this->type === 'reverse') {

            // "SELECT id FROM ranges WHERE start<='$ip_int' AND end>='$ip_int'"; 
            $dbdo = DB_DataObject::Factory('ranges');
            $dbdo->selectAdd();
            $dbdo->selectAdd('id');
            $dbdo->whereAdd("start<='{$this->ip}'");
            $dbdo->whereAdd("end>='{$this->ip}'");
            $dbdo->find(true);

            $test_range = new Range($dbdo->id);
            unset($dbdo);

            if ($test_range->type == 'dynamic' or $test_range->type == 'ddns') {

                return _("The IP address").' '.IP::int2ip($this->ip).' '.
                    _("is a dynamic address.  You must use a static address.");

            } // test for dyanmic range
               
            // this kind of thing really belongs in front-end validation
            $db = DB_DataObject::Factory('zone_range'); 
            $db->setRange($test_range->getId());
            $db->setZone($_SESSION['zone']);
            if (!$db->find() && !$user->is_admin()) {

                return _("The IP address").' '.IP::int2ip($this->ip).' '.
                    _("is not in the current zone");

            }

        } //check reverse pointers


        return true;
    }
    // }}}
    // {{{ validateZone()

    /**
      * Make sure domain is within this zone
      *
      * @return boolean false if forward pointer and zone has no access to this domain
      */
    function validateZone() {
        global $conf, $user;

        if (!$this->zone)
            return _("No zone was set for this pointer");

        // if this is a forward pointer, make sure this domain
        // is under this zone's control
        if (!strcasecmp($this->type, 'forward')) {

            $data = split_hostname($this->hostname);

            // SELECT id FROM domain WHERE name='$data->domain'";
            $dbdo = DB_DataObject::Factory('domain');
            $dbdo->selectAdd();
            $dbdo->selectAdd('id');
            $dbdo->name = $data->domain;
            $dbdo->find(true);
            $dbdo->fetch();

            // we'll need a zone object
            $z = DB_dataObject::Factory('zone_domain');
            $z->setZone($_SESSION['zone']);
            $z->setDomain($dbdo->id);

            // if zone has no access to this domain, check if the hostname
            // is a domain that the zone has access to
            if (!$z->find()) {

                $domains = $z->domains();

                $found = false;
                foreach ($domains as $dom) {
                    $domain = new Domain($dom);
                    if ($domain->name == $this->hostname) {
                        $found = true;
                        break;
                    }
                }

                if (!$found && !$user->is_admin()) {

                    return _("The zone")." $z->name ".
                        _("does not have access to this domain");

                }

            } //if zone has no access

        } //if forward pointer

        return true;
    }

    // }}}
    // {{{ validateType()

    function validateType() {
        global $conf, $user;

        // just in case, let's lower-case the type
        $this->type = strtolower($this->type);

        if (!strcmp($this->type, 'forward') && 
            !strcmp($this->type, 'reverse')) {

            return _("Pointer type must be 'forward' or 'reverse'");
        }

        return true;

    }
    // }}}
    // {{{ validateEnabled()

    function validateEnabled() {

        if ($this->enabled !== 1 AND $this->enabled !== 0)
            return false;

        return true;
    }
    // }}}

/* Internal Methods */
    // {{{ _history_text()

    function _history_text()
    {
        // HOSTNAME to xxx.xxx.xxx.xxx (TYPE)
        return $this->getHostname() . _(" to") . ' ' . 
            $this->getIp() . ' (' . $this->getType() . ' )';
    }

    // }}}

}

?>
