<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL: https://svn.osuosl.org/public/maintain-project/tags/release-3.0.0-RC1/class/dao/extended/soa.php $
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |       
// +------------------------------------------------------------------------+
// | Copyright (c) 2006 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Author(s): Frederic Wenzel <fred@osuosl.org>                           |
// +------------------------------------------------------------------------+
// $Id: soa.php 4550 2006-06-28 21:25:27Z wenzel $

/**
  * soa.php - contains the {@link SOA} class
  *
  * @author $Author: wenzel $
  * @filesource
  * @package    classes
  * @subpackage dao
  */

require_once DAODIR.'/Soa.php';
require_once 'Validate.php';

/**
  * A Start of Authority (SOA) Record
  *
  * @package    classes
  * @subpackage dao
  */
class Soa extends DAO_Soa {

// {{{ vars
    var $hmemail;       // email address of hostmaster
// }}}
    // {{{ Soa (constructor)

    /**
      * Constructor
      *
      * @param  int SOA ID (primary key)
      */
	function SOA ( $soa_id = 0 ) 
    {
        if ($soa_id) {
            $this->id = $soa_id;
            $this->get($this->id);
        }

    }
    // }}}

// Setters
    // {{{ setAll()

    /**
      * Call all set*() methods to 
      * ensure internal objects/variables
      * are up-to-date
      */
    function setAll() {
        
        $this->setHostmaster($this->hostmaster);
        $this->setDelegated($this->delegated);
    }

    // }}}
    // {{{ setHostmaster()
    /**
      * Set hostmaster email address, either in email format (with @) or
      * in DNS SOA record format (i.e. replace the @ by a .)
      */
    function setHostmaster($hm)
    {
        if (!$hm) return true;

        if ($atpos = strpos($hm, '@')) {
            // email format
            $email = $hm;
            $hmrecord = strtr($email, '@', '.');
        } else {
            // DNS SOA record format
            $atpos = strpos($hm, '.');
            $email = substr($hm, 0, $atpos).'@'.substr($hm, $atpos+1);
            $hmrecord = $hm;
        }
        
        $this->hostmaster = $hmrecord;
        $this->hmemail = $email;

        return true;
    }
    // }}}
    // {{{ setDelegated()

    /**
      * @param  mixed   true/false, 'true'/'false', 1/0
      */
    function setDelegated($deleg = '')
    {
        if ($deleg == true) {
            $this->delegated = 1;
        } else {
            $this->delegated = 0;
        }

        return true;
    }

    // }}}

// Getters
    // {{{ getHostmaster()
    function getHostmaster()
    {
        if (!$this->hostmaster) return false;
        
        // if hostmaster email is unavailable, set it first
        if (!$this->hmemail) {
            $this->setHostmaster($this->hostmaster);
        }
        
        // return host master email unless it is still unavailable
        if (!$this->hmemail)
            return false;
        else
            return $this->hmemail;
    }
    // }}}

// Validators
    // {{{ validateDomain()
    function validateDomain() {
        global $conf, $user;

        // has the domain been set?
        if (!isset($this->domain))
            return _("No domain was specified.");

        // does this domain already have a SOA record?
        $dbdo = DB_DataObject::Factory('soa');
        $dbdo->domain = $this->domain;
        if (isset($this->id))
            $dbdo->whereAdd("id != '{$this->id}'");

        // if so, return the error string
        if ($dbdo->find()) {
            // for the domain name:
            $domain = new Domain($this->domain);
            return _("A different SOA record for this domain already exists. Only one SOA record is possible per domain.");
        }

        return true;

    }
    // }}}
    // {{{ validatePrimary_Master()
    function validatePrimary_Master()
    {
        // make sure it's a valid hostname
        foreach (explode(".", $this->primary_master) as $part) {
            if (!preg_match("/^[a-zA-Z0-9][a-zA-Z0-9\-]{0,61}[a-zA-Z0-9]$/", $part) )
                return "$this->primary_master "._("is an invalid hostname");
        }
        return true;
    }
    // }}}
    // {{{ validateHostmaster()
    function validateHostmaster()
    {
        // if hostmaster email is unavailable, set it first
        if (!$this->hmemail) {
            $this->setHostmaster($this->hostmaster);
        }
        
        // check if email address is valid
        if (!Validate::email($this->hmemail))
            return _("Invalid hostmaster email provided");

        // in case it is a valid email, make sure there is no period before
        // the @ sign (which would mess up the SOA record).
        $localpart = substr($this->hmemail, 0, strpos($this->hmemail, '@'));
        if (strstr($localpart, '.'))
            return _('No "." allowed in local part of the hostmaster email address');

        return true;
    }
    // }}}
    // {{{ validateRefresh()
    function validateRefresh()
    {
        if (!is_numeric($this->refresh) || $this->refresh <= 0)
            return _("Refresh value has to be numeric and larger than 0");
        
        return true;
    }
    // }}}
    // {{{ validateRetry()
    function validateRetry()
    {
        if (!is_numeric($this->retry) || $this->retry <= 0)
            return _("Retry value has to be numeric and larger than 0");
        
        return true;
    }
    // }}}
    // {{{ validateExpire()
    function validateExpire()
    {
        if (!is_numeric($this->expire) || $this->expire <= 0)
            return _("Expire value has to be numeric and larger than 0");
        
        return true;
    }
    // }}}
    // {{{ validateTtl()
    function validateTtl()
    {
        if (!is_numeric($this->ttl) || $this->ttl <= 0)
            return _("TTL value has to be numeric and larger than 0");
        
        return true;
    }
    // }}}
    // {{{ validateDelegated()
    function validateDelegated()
    {
        return true;
    }
    // }}}
// Built-in Methods

// Internal Methods
    // {{{ _history_text()

    function _history_text()
    {
        return $this->getDomain() . ' --> ' . $this->getPrimary_Master();
    }

    // }}}
}

?>
