<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL: https://svn.osuosl.org/public/maintain-project/tags/release-3.0.0-RC1/class/dao/extended/vlan.php $
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |       
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Author(s): Daniel Robert <robert@osuosl.org>                           |
// +------------------------------------------------------------------------+
// $Id: vlan.php 4533 2006-06-26 23:52:30Z wenzel $

/**
  * vlan.php - contains the {@link VLAN} class
  *
  * @author $Author: wenzel $
  * @filesource
  * @package    classes
  * @subpackage dao
  */

include_once DAODIR.'/Vlan.php';

/**
  * A VLAN
  *
  * @package    classes
  * @subpackage dao
  */
class VLAN extends DAO_Vlan {

    //{{{ Constructor()

    /**
     *  Constructor
     *
     * @param   int id (primary key) of vlan
     */
	function VLAN ($id = 0)
    {
        global $conf;

        if ($id) {
            $this->id = $id;
            $this->get($this->id);
        }

	} // VLAN

    // }}}
/* Validators */
    //{{{ validateVland_id()

    function validateVlan_id()
    {
        global $conf;

        // make sure the vlan id was specified
        if (!$this->vlan_id)
            return _("Vlan_id not specified");

        // make sure the id is in the proper range
        if ( !ereg("^[[:digit:]]+$",$this->vlan_id) || ($this->vlan_id > 4049) )
            return _("VLAN ID must be an integer from 1-4049");
      
        // make sure this vlan id is not already in use
        // if the id is set then we are updating and don't need to check this
        $test = DB_DataObject::Factory('Vlan');
        $test->vlan_id = $this->vlan_id;
        if($test->find() && !isset($this->id))
            return _("VLAN ID already in use");

        // if we're here, we're clear...let's drink some beer
        return true;
    }

    //}}}	
    //{{{ validateName()

    function validateName()
    {
        global $conf;

        // has a name been set?
        if(!$this->name)
            return _("No name was set for this vlan");

        // make sure this name isn't in use
        // if the id is set then we are updating so we can skip this
        $test = DB_DataObject::Factory("Vlan");
        $test->name = $this->name;
        if($test->find() && !isset($this->id))
            return _("VLAN name already in use");
       
        // we're home free
        return true;
    }

    //}}}
/* Maintain Overloads */
    // {{{ _history_text()
    function _history_text()
    {
        // : NAME (vlan_id)
        return "$this->name ($this->vlan_id)";
    }
    // }}}
} // end of the vlan class

?>
