<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL: https://svn.osuosl.org/public/maintain2/trunk/class/auth.php $
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2006 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Author(s): Frederic Wenzel <fred@osuosl.org>                           |
// +------------------------------------------------------------------------+
// $Id: auth.php 3992 2005-11-08 21:25:54Z wenzel $

/**
  * email.php - Maintain Email Functionality
  *
  * @author $Author: wenzel $
  * @filesource
  * @package    classes
  */

require_once('Mail.php');
require_once('Mail/mime.php');

/**
  * Email functionality for Maintain.
  * Typically used to inform admins about critical errors.
  *
  * @package    classes
  * @subpackage auth
  */
class Email {
    // {{{ Constructor
    /**
      * Constructor
      */
    function Email()
    {
    }
    // }}}

    // {{{ adminEmail(.)
    /**
      * send an email to the admin(s) about an error
      *
      * @static
      * @param mixed PEAR_Error or string to be sent to the admin
      * @param string optional name of calling module, defaults to calling class name
      * @return mixed true if everything worked, PEAR_Error otherwise
      */
    function adminEmail($error, $caller = null)
    {
        global $conf;
    
        // check error message
        if (!(PEAR::isError($error) || is_string($error))) {
            return new PEAR_Error(_('Admin email could not be sent: No valid error message given!'));
        }

        // find default caller, if not given
        if (!is_string($caller)) {
            $bt = debug_backtrace();
            // caller's class name
            $caller = $bt[1]['class'];
        }
        
        // fetch recipients from config
        $recipients = $conf['email']['adminemail'];
        
        // generate subject and email body
        if (PEAR::isError($error)) {
            $subject = _("Error in module")." {$caller}";
            $body = "Module {$caller}: "._('An error occured in the module:')."\n\n";
            $body .= $error->getMessage();
        } else {
            $subject = _("Admin message from module")." {$caller}";
            $body = "Module {$caller}: "._("Your Maintain instance is sending you the following message:")."\n\n";
            $body .= $error;
        }
        
        // now send mail to admins
        return (Email::sendMaintainMail($recipients, $subject, $body));
    }
    // }}}

    // {{{ sendMaintainMail(.)
    /**
      * sends a mail to the given recipient(s) with a Maintain
      * "look and feel"
      *
      * @static
      * @param mixed recipient string or recipients string array
      * @param string subject line
      * @param string body text to be mailed
      * @return mixed true if no error occured, PEAR_Error otherwise
      */
    function sendMaintainMail($recipients, $subject, $text)
    {
        global $conf;
        
        // make Mail_Mime instance
        $mime = new Mail_Mime("\n");
        
        // make headers
        $hdrs = array(
            'From'      => $conf['email']['maintain_email_from'],
            'Subject'   => '[Maintain] '.$subject
            );
        
        // set body text
        // TODO Make a Maintain signature
        $mime->setTXTBody($text);
        
        // generate email content
        $mailbody = $mime->get();
        
        // now send email
        $mail =& Mail::factory($conf['email']['method'], $conf['email-server-params']);
        return $mail->send($conf['email']['adminemail'], $hdrs, $mailbody); // returns true or PEAR_Error
    }
    // }}}
}

?>
