<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL: https://svn.osuosl.org/public/maintain-project/tags/release-3.0.0-RC1/class/htdocs/datalist/UserDataList.php $
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Authors: Michael Clay <claym@osuosl.org>                               |
// |          Frederic Wenzel <fred@osuosl.org>                             |
// +------------------------------------------------------------------------+
// $Id: UserDataList.php 4587 2006-07-07 16:03:27Z morgabra $

/**
  * UserDataList.php - contains the {@link UserDataList} class
  *
  * @author $Author: morgabra $
  * @filesource
  * @package    htdocs
  * @subpackage datalists
  */

require_once(DAOEXT."/user.php");
require_once(HTCLASS.'/DB_DataObjectDataList.php');
require_once(HTCLASS.'/DB_DataObjectDataListSource.php');

/**
  * Table listing for Maintain users that are mapped to at least one zone
  *
  * @link   http://phphtmllib.newsblob.com/javadoc.php phpHtmlLib API Documentation
  * @link   http://phphtmllib.newsblob.com/doc/phpHtmlLib/DefaultGUIDatalist.html
            DefaultGUIDataList API Documentation
  * @package    htdocs
  * @subpackage datalists
  */
class UserDataList extends DB_DataObjectDataList
{

//{{{   get_data_source()

    function get_data_source()
    {

        $userobj = DB_DataObject::Factory('user');

        $src = &new DB_DataObjectDataListSource($userobj);
        $this->set_data_source($src);
        $this->_default_orderby = 'username';
    }

//}}}
//{{{   _user_setup()

    function _user_setup()
    {
        global $user;
       
        $this->add_header_item(_("Username"), '20%', 'username', SORTABLE, SEARCHABLE);
        
        if($user->is_admin())
            $this->add_header_item(_("Zones"), '20%');
        
        $this->add_header_item(_("Last Seen"),'25%');
        $this->add_header_item(_("Action"),'25%');
    }

//}}}
//{{{   build_column_item()

    function build_column_item($row_data, $col_name)
    {
        global $conf, $user;
        switch($col_name) {

        case _('Last Seen'):
            $obj = format_date($row_data['last_seen']);;
            if($row_data['last_seen'] === "0"){
                $obj = "User has never logged on";
            }
            break;
        case _('Action'): //static row is just links
            if ($user->username == $row_data['username']) {
                // don't allow deletion of yourself
                $delete = _("(no self-deletion)");
            } else {
                $delete = container(
                            html_a(web_root()."user.php?action=delete&amp;username=".
                            $row_data['username'],_("Delete User")));
            }
            $edit = html_a(web_root()."user.php?action=edit&amp;username=".$row_data['username'], _("Edit"));
            $obj = container($delete, "|", $edit);
            break;
        case _('Zones');
            $us = new User($row_data['username']);
            if(!$us->is_admin()) {
                $obj = container(count($us->zones()));
            } else {
                $obj = container(_("N/A, Full Admin"));
            }
            break;
        default:
            $obj = parent::build_column_item($row_data, $col_name);
        }

        return $obj;
    }

//}}}

}

?>
