<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL: https://svn.osuosl.org/public/maintain-project/trunk/class/htdocs/datalist/ZoneUserDataList.php $
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Authors: Michael Clay <claym@osuosl.org>                               |
// |          Frederic Wenzel <fred@osuosl.org>                             |
// +------------------------------------------------------------------------+
// $Id: ZoneUserDataList.php 4517 2006-06-26 16:02:13Z wenzel $

/**
  * ZoneUserDataList.php - contains the {@link UserDataList} class
  *
  * @author $Author: wenzel $
  * @filesource
  * @package    htdocs
  * @subpackage datalists
  */

require_once(DAOEXT."/user.php");
require_once(HTCLASS.'/DB_DataObjectDataList.php');
require_once(HTCLASS.'/DB_DataObjectDataListSource.php');

/**
  * Table listing for Maintain users that are mapped to at least one zone
  *
  * @link   http://phphtmllib.newsblob.com/javadoc.php phpHtmlLib API Documentation
  * @link   http://phphtmllib.newsblob.com/doc/phpHtmlLib/DefaultGUIDatalist.html
            DefaultGUIDataList API Documentation
  * @package    htdocs
  * @subpackage datalists
  */
class ZoneUserDataList extends DB_DataObjectDataList
{

//{{{   get_data_source()

    function get_data_source()
    {

        $userobj = DB_DataObject::Factory('zone_user');

        $src = &new DB_DataObjectDataListSource($userobj);
        $this->set_data_source($src);
        $this->_default_orderby = 'username';
    }

//}}}
//{{{   _user_setup()

    function _user_setup()
    {
        global $user;
       
        $this->add_header_item(_("Username"), '15%', 'username', SORTABLE, SEARCHABLE);
        $this->add_header_item(_("Access Level"),'15%','level',SORTABLE);
        
        if($user->is_admin())
            $this->add_header_item(_("Zone"), '15%', 'zone', SORTABLE);
        
        $this->add_header_item(_("Last Seen"),'15%');
        $this->add_header_item(_("Action"),'15%');
        $this->_datasource->setup_db_options(array('zone'=> $_SESSION['zone']));
    }

//}}}
//{{{   build_column_item()

    function build_column_item($row_data, $col_name)
    {
        global $conf, $user;
        switch($col_name) {
        case _('Access Level'):
            $obj = User::access_level($row_data['level']);
            break;
        case _('Last Seen'):
            $temp = new User($row_data['username']);
            $obj = format_date($temp->last_seen);
            break;
        case _('Action'): //static row is just links
            if ($user->username == $row_data['username']) {
                // don't allow deletion of yourself
                $delete = _("(no self-deletion)");
            } else {
                $delete = container(html_a(web_root()."user.php?action=delzoneuser".
                            "&amp;id=".$row_data['id'],_("Delete From Zone")),"|",
                            html_a(web_root()."user.php?action=delete&amp;username=".
                            $row_data['username'],_("Delete User")));
            }
            $edit = html_a(web_root()."user.php?action=edit&amp;username=".$row_data['username'], _("Edit"));
            $obj = container($delete, "|", $edit, "|", $this->_change_access_links($row_data));
            break;
        case _('Zone');
            $zn = new Zone($row_data['zone']);
            $obj = $zn->name . " (".$row_data['zone'].")";
            break;
        default:
            $obj = parent::build_column_item($row_data, $col_name);
        }

        return $obj;
    }

//}}}
//{{{ restrict_to_current_zone() (deprecated)

    /**
     *  This function determines if the list should be set to restrict the zone
     *  or not
     *
     *  @param  Bool $flag  Yes/no
     */
    function restrict_to_current_zone($flag)
    {
        if($flag === true)
            $this->_datasource->setup_db_options(array('zone'=> $_SESSION['zone']));
    }

//}}}

/* Internal Methods */
//{{{   _change_access_links()

    /**
     *  This method generates the links for altering a user's access level
     *
     *  @access private
     *  @param  Array   $row_data   Information for the row in question
     *  @return mixed   $res        A container of links or an error string
     */
    function _change_access_links($row_data)
    {
        $res = null;
        
        $userlink = html_a(web_root()."user.php?action=setlevel&amp;name=".$row_data['username'].
                            "&amp;zone_id=".$row_data['zone']."&amp;level=".ZONE_USER,
                            _("Make Zone User"));
        $guestlink = html_a(web_root()."user.php?action=setlevel&amp;name=".$row_data['username'].
                            "&amp;zone_id=".$row_data['zone']."&amp;level=".GUEST,
                            _("Make Zone Guest"));
        $adminlink = html_a(web_root()."user.php?action=setlevel&amp;name=".$row_data['username'].
                            "&amp;zone_id=".$row_data['zone']."&amp;level=".ZONE_ADMIN,
                            _("Make Zone Admin"));
                            
        switch($row_data['level']) {
        case 5: //zone guest
            $res = container($userlink,"|",$adminlink);
            break;
        case 25: //zone user
            $res = container($guestlink,"|",$adminlink);
            break;
        case 50: //zone admin
            $res = container($guestlink,"|",$userlink);
            break;
        case 100: //full admin
            $res = container($guestlink,"|",$userlink,"|",$adminlink);
            break;
        default:
            $res = _("Invalid User Type!");
        }
        return $res;
    }

//}}}

}

?>
