<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL: $
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2006 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Author(s): Daniel Robert <robert@osuosl.org>                           |
// +------------------------------------------------------------------------+
// $Id: $

/**
  * Constants and functions related to installation
  *
  * @package    install
  */

/** Update existing db is applicable */
define("UPDATE_DB", 1);
/** Install the database if needed*/
define("INSTALL_DB", 2);
/** Indicates the DAOs need to be written to the filesystem */
define("INSTALL_WRITE_DAO", 4);
/** The <dbname>.links.ini needs to be properly named */
define("RENAME_LINKS_INI", 8);
/** Indicates that an initial zone must be created */
define("INSTALL_INITIAL_ZONE", 16);
/** Indicates the admin password must be changed */
define("INSTALL_ADMIN_PASSWORD", 32);
/* this may go somewhere else */
define("MAINTAIN_VERSION", "300000");

// {{{ install_status()

/**
  * Determines which point in the installation process
  * the user is at, or simply returns true indicating
  * that maintain has already been installed.
  *
  * @return mixed   integer status code (defined constant) representing
  *                 the point the user is at in the installation process, or
  *                 true (boolean) if maintain has already been installed
  */
function install_status()
{
    global $conf;

    /* is there a database in place */
    $is_db = false;
    $tables = mysql_list_tables($conf['database']['database'], dbh());
    while ($row = mysql_fetch_row($tables)) {
        if ($row[0] == "host")  {
            $is_db = true;
            break;
        }
    }
    
    /* Check current version and see if we need to update */
    if ($is_db) {
        $dbdo = @DB_DataObject::Factory('update_info');
        $dbdo->setKey('db_version');
        $dbdo->setValue(MAINTAIN_VERSION);
        if (!$dbdo->find())
            return UPDATE_DB;
    } else    {
        return INSTALL_DB;   
    }
    // First test: DBDOs have been created
    // get the options
    $options = &PEAR::getStaticProperty('DB_DataObject','options');
    $prefix = $options['class_prefix'];

/* Nixing this for now
    // if 'user' and 'zone' don't exist as DBDOs, we need to create the DAOs
    if (!class_exists("{$prefix}zone") || !class_exists("{$prefix}user")) {
        return INSTALL_WRITE_DAO;
    }

    // well, we also want to make sure the <dbname>links.ini is properly named
    require_once(CLASSDIR.'/DAOWriter.php');
    $daowriter = new DAOWriter();
    if (!$daowriter->verifyLinksIni()) {
        return RENAME_LINKS_INI;
    }
*/
    /* If the db is not named maintain then we need to rename the links.ini */
    require_once(CLASSDIR.'/DAOWriter.php');        
    $dw = new DAOWriter();
    if ($dw->verifyLinksIni(false) !== true)
        return RENAME_LINKS_INI;

    // next test: are there any zones?
    $dbdo = DB_DataObject::Factory('zone');

    // if not, we need to create the initial zone
    if (!$dbdo->find()) {
        return INSTALL_INITIAL_ZONE;
    }
    unset($dbdo);

    // next test: make sure the administrator's password has been changed
    $admin = new User('admin');

    // if not, send them to the 'set admin password' page
    if ($admin->getPassword() == sha1('changeme')) {
        return INSTALL_ADMIN_PASSWORD;
    }
    unset($admin);

    return true;
}

// }}}

//{{{ install_insert_db()
    /* This function will attempt to write the database schema to the db
     *
     *
     *
     */
    function install_insert_db()
    {
        $dbh = dbh();
        /* DB exists lets add some tables */
        $script = $conf['paths']['prefix']."/install/sql/maintain.sql"; 
        $query = fread(fopen($script, "r"), filesize($script)); 

        $stmts = explode(";", $query);
        foreach ($stmts as $sql)
            if ($sql[0] != '-' && $sql[0] != '#')
                mysql_query($sql, $dbh);
        
    }
//}}}
?>
